var NAVTREEINDEX7 =
{
"md_docs_2EntitiesComponents.html":[4],
"md_docs_2EntitiesComponents.html#clearing":[4,1,2],
"md_docs_2EntitiesComponents.html#components-1":[4,2],
"md_docs_2EntitiesComponents.html#components-are-entities":[4,2,1],
"md_docs_2EntitiesComponents.html#creation":[4,1,0],
"md_docs_2EntitiesComponents.html#deletion":[4,1,1],
"md_docs_2EntitiesComponents.html#disabling":[4,1,8],
"md_docs_2EntitiesComponents.html#disabling-1":[4,2,5],
"md_docs_2EntitiesComponents.html#entities-1":[4,1],
"md_docs_2EntitiesComponents.html#introduction":[4,0],
"md_docs_2EntitiesComponents.html#liveliness-checking":[4,1,3],
"md_docs_2EntitiesComponents.html#manual-ids":[4,1,4],
"md_docs_2EntitiesComponents.html#manual-versioning":[4,1,5],
"md_docs_2EntitiesComponents.html#names":[4,1,7],
"md_docs_2EntitiesComponents.html#operations":[4,2,0],
"md_docs_2EntitiesComponents.html#ranges":[4,1,6],
"md_docs_2EntitiesComponents.html#registration":[4,2,2],
"md_docs_2EntitiesComponents.html#runtime-type-registration":[4,2,2,0],
"md_docs_2EntitiesComponents.html#singletons":[4,2,4],
"md_docs_2EntitiesComponents.html#unregistration":[4,2,3],
"md_docs_2FAQ.html":[1],
"md_docs_2FAQ.html#are-relationships-just-a-component-with-an-entity-handle":[1,20],
"md_docs_2FAQ.html#can-flecs-be-compiled-to-web-assembly":[1,10],
"md_docs_2FAQ.html#can-flecs-serialize-components":[1,14],
"md_docs_2FAQ.html#can-i-add-or-remove-components-from-within-a-system":[1,25],
"md_docs_2FAQ.html#can-i-create-systems-outside-of-the-main-function":[1,21],
"md_docs_2FAQ.html#can-i-use-flecs-with-c14-or-higher":[1,2],
"md_docs_2FAQ.html#can-i-use-flecs-without-using-systems":[1,23],
"md_docs_2FAQ.html#can-i-use-my-own-scheduler-implementation":[1,22],
"md_docs_2FAQ.html#can-i-use-stdvector-or-other-types-inside-components":[1,3],
"md_docs_2FAQ.html#does-the-explorer-collect-data-from-my-application":[1,17],
"md_docs_2FAQ.html#how-do-i-detect-which-entities-have-changed":[1,19],
"md_docs_2FAQ.html#how-does-flecs-compare-with-entt":[1,5],
"md_docs_2FAQ.html#is-flecs-used-for-commercial-projects":[1,6],
"md_docs_2FAQ.html#what-does-a-locked_storage-error-mean":[1,26],
"md_docs_2FAQ.html#what-is-an-archetype":[1,4],
"md_docs_2FAQ.html#what-is-an-ecs":[1,0],
"md_docs_2FAQ.html#what-is-the-difference-between-add--set-why-do-both-exist":[1,13],
"md_docs_2FAQ.html#why-am-i-getting-an-use-of-undeclared-identifier-flecs_id--compiler-error":[1,11],
"md_docs_2FAQ.html#why-are-my-entity-ids-so-large":[1,12],
"md_docs_2FAQ.html#why-are-queries-slow":[1,7],
"md_docs_2FAQ.html#why-are-queries-taking-up-a-lot-of-ram":[1,8],
"md_docs_2FAQ.html#why-cant-i-see-component-values-in-the-explorer":[1,18],
"md_docs_2FAQ.html#why-does-the-explorer-not-work":[1,16],
"md_docs_2FAQ.html#why-does-the-lookup-function-not-find-my-entity":[1,24],
"md_docs_2FAQ.html#why-is-flecs-so-large":[1,15],
"md_docs_2FAQ.html#why-is-flecs-written-in-c":[1,1],
"md_docs_2FAQ.html#why-is-my-system-called-multiple-times-per-frame":[1,9],
"md_docs_2FlecsQueryLanguage.html":[6],
"md_docs_2FlecsQueryLanguage.html#access-modifiers-1":[6,4],
"md_docs_2FlecsQueryLanguage.html#advanced":[6,9],
"md_docs_2FlecsQueryLanguage.html#andfrom":[6,3,3],
"md_docs_2FlecsQueryLanguage.html#any-wildcard-_":[6,5,1],
"md_docs_2FlecsQueryLanguage.html#components-3":[6,2,0],
"md_docs_2FlecsQueryLanguage.html#dependent-variables":[6,9,3],
"md_docs_2FlecsQueryLanguage.html#equality-operators-1":[6,9,0],
"md_docs_2FlecsQueryLanguage.html#example":[6,1],
"md_docs_2FlecsQueryLanguage.html#introduction-2":[6,0],
"md_docs_2FlecsQueryLanguage.html#lookup-variables-1":[6,9,1],
"md_docs_2FlecsQueryLanguage.html#member-matching":[6,9,2],
"md_docs_2FlecsQueryLanguage.html#not":[6,3,0],
"md_docs_2FlecsQueryLanguage.html#notfrom":[6,3,4],
"md_docs_2FlecsQueryLanguage.html#operators":[6,3],
"md_docs_2FlecsQueryLanguage.html#optional":[6,3,2],
"md_docs_2FlecsQueryLanguage.html#or":[6,3,1],
"md_docs_2FlecsQueryLanguage.html#orfrom":[6,3,5],
"md_docs_2FlecsQueryLanguage.html#pairs-1":[6,2,1],
"md_docs_2FlecsQueryLanguage.html#query-scopes-1":[6,9,4],
"md_docs_2FlecsQueryLanguage.html#singleton-source":[6,7,1],
"md_docs_2FlecsQueryLanguage.html#source-1":[6,7],
"md_docs_2FlecsQueryLanguage.html#static-source":[6,7,0],
"md_docs_2FlecsQueryLanguage.html#the-basics":[6,2],
"md_docs_2FlecsQueryLanguage.html#traversal":[6,8],
"md_docs_2FlecsQueryLanguage.html#variable-source":[6,7,2],
"md_docs_2FlecsQueryLanguage.html#variables-1":[6,6],
"md_docs_2FlecsQueryLanguage.html#wildcard-wildcard-":[6,5,0],
"md_docs_2FlecsQueryLanguage.html#wildcards-1":[6,5],
"md_docs_2FlecsRemoteApi.html":[14],
"md_docs_2FlecsRemoteApi.html#delete-component":[14,3,5],
"md_docs_2FlecsRemoteApi.html#delete-entity":[14,3,2],
"md_docs_2FlecsRemoteApi.html#example-3":[14,3,8,0],
"md_docs_2FlecsRemoteApi.html#example-4":[14,3,9,0],
"md_docs_2FlecsRemoteApi.html#examples-10":[14,3,6,0],
"md_docs_2FlecsRemoteApi.html#examples-11":[14,3,7,1],
"md_docs_2FlecsRemoteApi.html#examples-4":[14,3,0,1],
"md_docs_2FlecsRemoteApi.html#examples-5":[14,3,1,0],
"md_docs_2FlecsRemoteApi.html#examples-6":[14,3,2,0],
"md_docs_2FlecsRemoteApi.html#examples-7":[14,3,3,0],
"md_docs_2FlecsRemoteApi.html#examples-8":[14,3,4,0],
"md_docs_2FlecsRemoteApi.html#examples-9":[14,3,5,0],
"md_docs_2FlecsRemoteApi.html#explorer-quickstart":[14,0],
"md_docs_2FlecsRemoteApi.html#get-component":[14,3,3],
"md_docs_2FlecsRemoteApi.html#get-entity":[14,3,0],
"md_docs_2FlecsRemoteApi.html#get-query":[14,3,7],
"md_docs_2FlecsRemoteApi.html#get-world":[14,3,8],
"md_docs_2FlecsRemoteApi.html#javascript-library":[14,2],
"md_docs_2FlecsRemoteApi.html#json-serialization":[14,1,0],
"md_docs_2FlecsRemoteApi.html#options":[14,3,0,0],
"md_docs_2FlecsRemoteApi.html#options-1":[14,3,7,0],
"md_docs_2FlecsRemoteApi.html#put-component":[14,3,4],
"md_docs_2FlecsRemoteApi.html#put-entity":[14,3,1],
"md_docs_2FlecsRemoteApi.html#put-script":[14,3,9],
"md_docs_2FlecsRemoteApi.html#put-toggle":[14,3,6],
"md_docs_2FlecsRemoteApi.html#reference-1":[14,3],
"md_docs_2FlecsRemoteApi.html#rest-api":[14,1,1],
"md_docs_2FlecsRemoteApi.html#usage-1":[14,1],
"md_docs_2FlecsScript.html":[12],
"md_docs_2FlecsScript.html#advanced-features":[12,3],
"md_docs_2FlecsScript.html#api":[12,6],
"md_docs_2FlecsScript.html#builtin-kinds":[12,2,6,0],
"md_docs_2FlecsScript.html#comma-operator":[12,4],
"md_docs_2FlecsScript.html#component-values":[12,3,4],
"md_docs_2FlecsScript.html#components-4":[12,2,3],
"md_docs_2FlecsScript.html#default-components":[12,3,6],
"md_docs_2FlecsScript.html#entities-2":[12,2,0],
"md_docs_2FlecsScript.html#entity-kinds":[12,2,6],
"md_docs_2FlecsScript.html#example-2":[12,1],
"md_docs_2FlecsScript.html#if-statement":[12,3,5],
"md_docs_2FlecsScript.html#inheritance":[12,2,7],
"md_docs_2FlecsScript.html#introduction-7":[12,0],
"md_docs_2FlecsScript.html#managed-script":[12,6,2],
"md_docs_2FlecsScript.html#module-statement":[12,3,0],
"md_docs_2FlecsScript.html#namespacing-1":[12,2,4],
"md_docs_2FlecsScript.html#pairs-2":[12,2,2],
"md_docs_2FlecsScript.html#relationship-hierarchies":[12,2,8],
"md_docs_2FlecsScript.html#run-multiple-times":[12,6,1],
"md_docs_2FlecsScript.html#run-once":[12,6,0],
"md_docs_2FlecsScript.html#semicolon-operator":[12,3,7],
"md_docs_2FlecsScript.html#singletons-3":[12,2,5],
"md_docs_2FlecsScript.html#tags":[12,2,1],
"md_docs_2FlecsScript.html#templates":[12,5],
"md_docs_2FlecsScript.html#the-basics-2":[12,2],
"md_docs_2FlecsScript.html#using-statement":[12,3,1],
"md_docs_2FlecsScript.html#variables-2":[12,3,3],
"md_docs_2FlecsScript.html#with-statement":[12,3,2],
"md_docs_2Manual.html":[15],
"md_docs_2Manual.html#api-design":[15,2],
"md_docs_2Manual.html#autotoc_md1-performance":[15,1,0],
"md_docs_2Manual.html#autotoc_md2-portability":[15,1,1],
"md_docs_2Manual.html#autotoc_md3-reusability":[15,1,2],
"md_docs_2Manual.html#autotoc_md4-usability":[15,1,3],
"md_docs_2Manual.html#autotoc_md5-extensibility":[15,1,4],
"md_docs_2Manual.html#autotoc_md6-have-fun":[15,1,5],
"md_docs_2Manual.html#deferred-operations":[15,4],
"md_docs_2Manual.html#design-goals":[15,1],
"md_docs_2Manual.html#error-handling":[15,2,2],
"md_docs_2Manual.html#idempotence":[15,2,1],
"md_docs_2Manual.html#introduction-8":[15,0],
"md_docs_2Manual.html#macros":[15,2,4],
"md_docs_2Manual.html#memory-ownership":[15,2,3],
"md_docs_2Manual.html#modules-1":[15,3],
"md_docs_2Manual.html#modules-in-c":[15,3,0],
"md_docs_2Manual.html#naming-conventions":[15,2,0],
"md_docs_2MigrationGuide.html":[16],
"md_docs_2MigrationGuide.html#addons-1":[16,13],
"md_docs_2MigrationGuide.html#caching":[16,0,0],
"md_docs_2MigrationGuide.html#component-disabling":[16,9],
"md_docs_2MigrationGuide.html#ecs_new":[16,6],
"md_docs_2MigrationGuide.html#ensure--get_mut":[16,5],
"md_docs_2MigrationGuide.html#entity-names-1":[16,4],
"md_docs_2MigrationGuide.html#flecs-script-1":[16,7],
"md_docs_2MigrationGuide.html#inheritance-1":[16,8],
"md_docs_2MigrationGuide.html#iter-function":[16,0,1],
"md_docs_2MigrationGuide.html#misc":[16,14],
"md_docs_2MigrationGuide.html#observers-1":[16,2],
"md_docs_2MigrationGuide.html#queries-2":[16,0],
"md_docs_2MigrationGuide.html#query-dsl":[16,0,2],
"md_docs_2MigrationGuide.html#snapshots":[16,11],
"md_docs_2MigrationGuide.html#systems--pipelines":[16,1],
"md_docs_2MigrationGuide.html#term-iterators":[16,3],
"md_docs_2MigrationGuide.html#tree-flattening":[16,12],
"md_docs_2MigrationGuide.html#union-relationships":[16,10],
"md_docs_2ObserversManual.html":[8],
"md_docs_2ObserversManual.html#adding-an-isa-pair":[8,2,3,0],
"md_docs_2ObserversManual.html#bad-use-cases-for-observers":[8,2,0,2],
"md_docs_2ObserversManual.html#children-are-cleaned-up-before-parents":[8,11,1,6],
"md_docs_2ObserversManual.html#custom-event-order-is-maintained":[8,11,1,4],
"md_docs_2ObserversManual.html#custom-events":[8,10],
"md_docs_2ObserversManual.html#enqueue-vs-emit":[8,10,1],
"md_docs_2ObserversManual.html#entity-observers":[8,10,0],
"md_docs_2ObserversManual.html#event-downgrading":[8,4,1],
"md_docs_2ObserversManual.html#event-forwarding":[8,9],
"md_docs_2ObserversManual.html#event-inversion":[8,4,2],
"md_docs_2ObserversManual.html#event-order-is-undefined-between-entities":[8,11,1,1],
"md_docs_2ObserversManual.html#event-propagation":[8,8],
"md_docs_2ObserversManual.html#example-1":[8,1],
"md_docs_2ObserversManual.html#filter-terms":[8,4,0],
"md_docs_2ObserversManual.html#fixed-source-terms":[8,7],
"md_docs_2ObserversManual.html#good-use-cases-for-observers":[8,2,0,1],
"md_docs_2ObserversManual.html#hooks-and-events":[8,11,1,5],
"md_docs_2ObserversManual.html#introduction-3":[8,0],
"md_docs_2ObserversManual.html#limitations-1":[8,2,0,0],
"md_docs_2ObserversManual.html#monitors":[8,5],
"md_docs_2ObserversManual.html#multi-event-observers":[8,3],
"md_docs_2ObserversManual.html#multi-term-observers":[8,4],
"md_docs_2ObserversManual.html#observer-disabling":[8,11,0],
"md_docs_2ObserversManual.html#observer-execution":[8,11],
"md_docs_2ObserversManual.html#observer-order-is-undefined":[8,11,1,0],
"md_docs_2ObserversManual.html#observer-ordering":[8,11,1],
"md_docs_2ObserversManual.html#observers-vs-hooks":[8,2,0,3],
"md_docs_2ObserversManual.html#onadd--onremove-order-is-undefined":[8,11,1,2],
"md_docs_2ObserversManual.html#onadd-events":[8,2,1],
"md_docs_2ObserversManual.html#onremove-events":[8,2,4],
"md_docs_2ObserversManual.html#onset-and-inheritance":[8,2,3],
"md_docs_2ObserversManual.html#onset-events":[8,2,2],
"md_docs_2ObserversManual.html#onset-order-is-maintained":[8,11,1,3],
"md_docs_2ObserversManual.html#removing-an-override":[8,2,3,1],
"md_docs_2ObserversManual.html#setting-an-inherited-component":[8,2,3,2],
"md_docs_2ObserversManual.html#singletons-2":[8,7,0],
"md_docs_2ObserversManual.html#the-basics-1":[8,2],
"md_docs_2ObserversManual.html#usage":[8,2,0],
"md_docs_2ObserversManual.html#yield-existing":[8,6],
"md_docs_2PrefabsManual.html":[9],
"md_docs_2PrefabsManual.html#auto-overriding":[9,4],
"md_docs_2PrefabsManual.html#component-inheritance-1":[9,2],
"md_docs_2PrefabsManual.html#component-overriding":[9,3],
"md_docs_2PrefabsManual.html#introduction-4":[9,0],
"md_docs_2PrefabsManual.html#prefab-hierarchies":[9,6],
"md_docs_2PrefabsManual.html#prefab-slots":[9,7],
"md_docs_2PrefabsManual.html#prefab-types-c-c":[9,8],
"md_docs_2PrefabsManual.html#prefab-variants":[9,5],
"md_docs_2PrefabsManual.html#the-prefab-tag":[9,1],
"md_docs_2Queries.html":[5],
"md_docs_2Queries.html#access-modifiers":[5,6,3],
"md_docs_2Queries.html#all":[5,3,2,2],
"md_docs_2Queries.html#and-operator":[5,6,5],
"md_docs_2Queries.html#andfrom-orfrom-notfrom-operators":[5,6,10],
"md_docs_2Queries.html#auto":[5,3,2,1],
"md_docs_2Queries.html#cache-kinds":[5,3,2],
"md_docs_2Queries.html#caching-what-is-it":[5,3,0],
"md_docs_2Queries.html#change-detection":[5,6,17],
"md_docs_2Queries.html#component-inheritance":[5,6,20],
"md_docs_2Queries.html#components-2":[5,6,0],
"md_docs_2Queries.html#creating-queries":[5,4],
"md_docs_2Queries.html#default":[5,3,2,0],
"md_docs_2Queries.html#definitions":[5,1],
"md_docs_2Queries.html#empty-archetype-optimization":[5,3,3,1],
"md_docs_2Queries.html#equality-operators":[5,6,9],
"md_docs_2Queries.html#examples-1":[5,2],
"md_docs_2Queries.html#group-iterators":[5,6,19,0],
"md_docs_2Queries.html#grouping":[5,6,19],
"md_docs_2Queries.html#introduction-1":[5,0],
"md_docs_2Queries.html#iteration":[5,5],
"md_docs_2Queries.html#iteration-1":[5,6,14,1],
"md_docs_2Queries.html#limitations":[5,6,14,2],
"md_docs_2Queries.html#lookup-variables":[5,6,15,1],
"md_docs_2Queries.html#member-value-queries":[5,6,16],
"md_docs_2Queries.html#none":[5,3,2,3],
"md_docs_2Queries.html#not-operator":[5,6,7],
"md_docs_2Queries.html#operator-overview":[5,6,4]
};
